#!/usr/lib/R/bin/Rscript

# Jean-Marie Lepioufle
# NILU - nilu.no
# 2019-02-21
# Get timeseries from a service by using friendlyr

'friendlyr

Usage:
  friendlyr.R service <service> fromDate <fromDate> toDate <toDate> precision <precision> timeResolution <timeResolution> element_id <element_id> station_id <station_id> username <username> password <password> result <result> name <name>
  conv.R (-h | --help)
  conv.R --version

Options:
  -h --help         Show this screen.
  --version         Show version.

Outcomes:
  timeserie:  Timeserie of as a friendlyts data.frame.

' -> doc


#library(docopt)
arguments <- docopt::docopt(doc, version = 'conv version 0.0.1')

###################
# requirement     #
###################
suppressPackageStartupMessages(require("friendlyr"))

###################
# init parameters #
###################

cat("Initialising parameters... \n")


service <- tryCatch({

  res <- as.character(arguments$service)
  if(!(res %in% c("luftlyr","innoly","frostlyr","d.luft.oslyr","d.eipalyr","d.eimetlyr"))) stop("'service' need to be one of these: 'luftlyr','innoly','frostlyr','d.luft.oslyr','d.eipalyr','d.eimetlyr'")
  res

}, error = function(err) {

  print(paste("Error in argument 'service':  ",err))
  print("It will crash.")

})

fromDate <- tryCatch({

  res <- as.character(arguments$fromDate)
  # add some filter
  res

}, error = function(err) {

  print(paste("Error in argument 'fromDate':  ",err))
  print("It will crash.")

})


toDate <- tryCatch({

  res <- as.character(arguments$toDate)
  # add some filter
  res

}, error = function(err) {

  print(paste("Error in argument 'toDate':  ",err))
  print("It will crash.")

})

precision <- tryCatch({

  res <- as.character(arguments$precision)
  if(!(res %in% c("second","minute","hourly","daily","monthly","yearly"))) stop("'service' need to be one of these: 'second','minute','hourly','daily','monthly','yearly'")
  res

}, error = function(err) {

  print(paste("Error in argument 'precision':  ",err))
  print("It will crash.")

})

timeResolution <- tryCatch({

  res <- as.character(arguments$timeResolution)
  if(!(res %in% c("second","minute","hourly","daily","monthly","yearly"))) stop("'service' need to be one of these: 'second','minute','hourly','daily','monthly','yearly'")
  res

}, error = function(err) {

  print(paste("Error in argument 'timeResolution':  ",err))
  print("It will crash.")

})

element_id <- tryCatch({

  res <- as.character(arguments$element_id)
  # add some filter
  res

}, error = function(err) {

  print(paste("Error in argument 'element_id':  ",err))
  print("It will crash.")

})

station_id <- tryCatch({

  res <- as.character(arguments$station_id)
  # add some filter
  res

}, error = function(err) {

  print(paste("Error in argument 'station_id':  ",err))
  print("It will crash.")

})

username <- tryCatch({

  res <- as.character(arguments$username)
  # add some filter
  res

}, error = function(err) {

  print(paste("Error in argument 'username':  ",err))
  print("It will crash.")

})

password <- tryCatch({

  res <- as.character(arguments$password)
  # add some filter
  res

}, error = function(err) {

  print(paste("Error in argument 'password':  ",err))
  print("It will crash.")

})

# get path of where to store the result
result <- tryCatch({

  res <- normalizePath(file.path(as.character(arguments$result),"friendlyr"),mustWork = FALSE)
  dir.create(res, showWarnings = FALSE, recursive = TRUE)
  res

}, error = function(err) {

  print(paste("Error in argument 'result':  ",err))
  print("'result' get its default value: '~'")

  res <- normalizePath(file.path(path.expand('~'),"friendlyr"),mustWork = FALSE)
  dir.create(res, showWarnings = FALSE, recursive = TRUE)
  return(res)

})


name <- tryCatch({

  res <- as.character(arguments$name)
  # add some filter
  res

}, error = function(err) {

  print(paste("Error in argument 'name':  ",err))
  print("It will crash.")

})


#######################
# get timeseries data #
#######################
df <- friendlyr::ts(service=service,username=username,password=password,
                 fromDate=fromDate,toDate=toDate,precision=precision,timeResolution=timeResolution,
                 element_id=element_id,station_id=station_id)


#save
pathfile <- normalizePath(file.path(path, paste0(name,".csv")),mustWork = FALSE)
write.csv(df,file=pathfile,row.names=FALSE)
